from typing import List, Tuple

import requests
import whois
from requests import Session
from requests.adapters import HTTPAdapter
from requests.packages.urllib3.util import Retry

from servergrimoire.plugin import Plugin

MARKDOWN = """
# Page Checker

Save the HTTP/HTTPS status of the url
"""

TIMEOUT = 5
s = Session()
retries = Retry(total=3, backoff_factor=0)
adapter = HTTPAdapter(max_retries=retries)
s.mount("https://", adapter)
s.mount("http://", adapter)


class PageChecker(Plugin):
    def can_handle(self, directive: str) -> bool:
        return directive == "p"

    @staticmethod
    def get_directives() -> List[str]:
        return ["page_checker"]

    def execute(self, directive: str, data: dict) -> dict:
        w = whois.whois(data["url"])
        try:
            try:
                if "https" not in data["url"]:
                    url = f"https://{data['url']}"
                else:
                    url = data["url"]
                status_code = s.head(
                    url, allow_redirects=True, timeout=TIMEOUT
                ).status_code
            except requests.exceptions.SSLError:
                url = f"http://{data['url']}"
                status_code = s.head(
                    url, allow_redirects=True, timeout=TIMEOUT
                ).status_code
            self.logger.info(w)
        except requests.exceptions.ConnectTimeout:
            status_code = 408
        except Exception:
            status_code = 400

        output_strng = {
            "status": status_code,
            "url": url,
        }
        self.logger.info(output_strng)
        return output_strng

    def stats(
        self, directive: str, data: dict
    ) -> Tuple[List[List], List[List]]:
        stat_temp: dict = {}
        other = []
        try:
            for key in data.keys():
                data_filter = data[key][directive]
                stat_temp[str(data_filter["status"])] = 1
                if not (200 <= data_filter["status"] < 300):
                    status = data_filter["status"]
                    try:
                        if 300 <= status < 400:
                            color = "blue"
                        elif 400 <= status < 500:
                            color = "yellow"
                        elif 500 <= status < 600:
                            color = "red"
                        else:
                            color = "cyan"
                        other.append(
                            [
                                f"[{color}]{data_filter['url']}",
                                f"[{color}]{data_filter['status']}",
                            ]
                        )
                    except KeyError:
                        pass
            stats = []
            for key, value in stat_temp.items():
                temp = [key, value]
                stats.append(temp)

            return stats, other
        except KeyError:
            return [], []

    def header_stats(self) -> List[str]:
        return ["Status", "Number"]

    def header_error(self) -> List[str]:
        return ["Url", "Status"]

    def title_stats(self) -> str:
        return "Page Checker Stats"

    def title_error(self) -> str:
        return "Page Checker Error"

    def get_markdown(self):
        """
        Return info text as Markdown
        """
        return MARKDOWN



import logging
from typing import List, Tuple

from rich.console import Console
from rich.logging import RichHandler
from rich.markdown import Markdown


class Plugin(object):
    """
    Abstract base class for commands that process directives.
    """

    def __init__(self):
        FORMAT = "%(message)s"
        logging.basicConfig(
            level="NOTSET",
            format=FORMAT,
            datefmt="[%X]",
            handlers=[RichHandler()],
        )

        self.logger = logging.getLogger("rich")

    @staticmethod
    def get_directives() -> List[str]:
        """
        Returns the directives.
        """
        raise NotImplementedError

    def can_handle(self, directive: str) -> bool:
        """
        Returns true if the Plugin can handle the directive.
        """
        raise NotImplementedError

    def execute(self, directive: str, data: dict) -> dict:
        """
        Executes the directive.
        """
        raise NotImplementedError

    def stats(
        self, directive: str, data: dict
    ) -> Tuple[List[List], List[List]]:
        """
        Return the stats for the directive
        """
        raise NotImplementedError

    def get_markdown(self):
        """
        Return info text as Markdown
        """
        raise NotImplementedError

    def info(self):
        """
        Return info of the directive
        """
        console = Console()
        md = Markdown(self.get_markdown())
        console.print(md)

    def header_stats(self) -> List[str]:
        raise NotImplementedError

    def header_error(self) -> List[str]:
        raise NotImplementedError

    def title_stats(self) -> str:
        raise NotImplementedError

    def title_error(self) -> str:
        raise NotImplementedError



from typing import List, Tuple

import dns.resolver

from servergrimoire.plugin import Plugin

MARKDOWN = """
# DNSL Lookup

Save the DNSL lookup of the domain
"""


class DNSLookup(Plugin):
    def can_handle(self, directive: str) -> bool:
        return directive == "dns_lookup"

    @staticmethod
    def get_directives() -> [str]:
        return ["dns_lookup"]

    def execute(self, directive: str, data: dict) -> dict:
        domain = data["url"]
        array_input = [
            (domain, "A"),
            (domain, "MX"),
            ("mail." + domain, "A"),
            (domain, "NS"),
            (domain, "TXT"),
        ]
        output = {}
        for query, label in array_input:
            try:
                output[label] = []
                for rdata in dns.resolver.resolve(query, label):
                    output[label].append(str(rdata))
            except Exception:
                output.pop(label)
                self.logger.info(f"Not found {label} for {domain}")
        return output

    def stats(
        self, directive: str, data: dict
    ) -> Tuple[List[List], List[List]]:
        stats = {"MX": 0, "NS": 0, "TXT": 0, "A": 0}
        for key in data.keys():
            data_filter = data[key][directive]
            self.logger.debug(data_filter)
            for e in data_filter:
                stats[e] += len(data_filter[e])
            self.logger.debug(stats)
        return [
            ["MX", stats["MX"]],
            ["NS", stats["NS"]],
            ["TXT", stats["TXT"]],
            ["A", stats["A"]],
        ], []

    def header_stats(self) -> List[str]:
        return ["Type", "Number"]

    def header_error(self) -> List[str]:
        return ["Type", "Number"]

    def title_stats(self) -> str:
        return "DNS Lookup Stats"

    def title_error(self) -> str:
        return "DNS Lookup Error"

    def get_markdown(self):
        """
        Return info text as Markdown
        """
        return MARKDOWN



import datetime
import socket
import ssl
from typing import Tuple, List

from servergrimoire.plugin import Plugin

MARKDOWN = """
# SSL Verify

Plugin for get some info of the SSL certificate of a domain
"""


def broken_response(url) -> {str, str, str}:
    return {
        "status": "KO",
        "expired": "****-**-** **:**:**",
        "domain": url,
        "organization_name": "***",
    }


class SSLVerify(Plugin):
    def can_handle(self, directive: str) -> bool:
        return directive == "ssl_check"

    @staticmethod
    def get_directives() -> [str]:
        return ["ssl_check"]

    def __ssl_valid_time_remaining(
        self, hostname: str
    ) -> Tuple[datetime.datetime, str]:
        ssl_date_fmt = r"%b %d %H:%M:%S %Y %Z"

        context = ssl.create_default_context()
        conn = context.wrap_socket(
            socket.socket(socket.AF_INET),
            server_hostname=hostname,
        )

        self.logger.debug("Connect to {}".format(hostname))
        conn.connect((hostname, 443))
        ssl_info = conn.getpeercert()
        # parse the string from the certificate into a Python datetime object
        self.logger.info(ssl_info)
        try:
            organizzator = ssl_info["issuer"][2][0][1]
            self.logger.info(f"How relaise it {organizzator}")
        except Exception as e:
            organizzator = "***"
            self.logger.info(e)
        return (
            datetime.datetime.strptime(ssl_info["notAfter"], ssl_date_fmt),
            organizzator,
        )

    def execute(self, directive: str, data: dict) -> dict:
        """Return test message for hostname cert expiration."""
        limit = datetime.datetime.now() + datetime.timedelta(days=30)
        output_strng = None
        url = data["url"]
        try:
            will_expire_in, organizzator = self.__ssl_valid_time_remaining(url)
        except ResourceWarning:
            output_strng = broken_response(url)
        except OSError:
            output_strng = broken_response(url)
        except FileNotFoundError:
            output_strng = broken_response(url)
        except socket.gaierror:
            output_strng = broken_response(url)
        except ssl.CertificateError:
            output_strng = broken_response(url)
        except TimeoutError:
            output_strng = broken_response(url)
        except ssl.SSLError:
            output_strng = broken_response(url)
        except socket.timeout:
            output_strng = broken_response(url)
        else:
            self.logger.info(
                f"will_expire {will_expire_in}, limit {limit}, today {datetime.datetime.now()}"
            )
            if will_expire_in is None:
                output_strng = broken_response(url)
            elif will_expire_in < datetime.datetime.now():
                output_strng = {
                    "status": "KO",
                    "expired": str(will_expire_in),
                    "domain": url,
                    "organization_name": organizzator,
                }
            elif will_expire_in < limit:
                output_strng = {
                    "status": "XX",
                    "expired": str(will_expire_in),
                    "domain": url,
                    "organization_name": organizzator,
                }
            else:
                output_strng = {
                    "status": "OK",
                    "expired": str(will_expire_in),
                    "domain": url,
                    "organization_name": organizzator,
                }
        self.logger.info(f"{directive} return {output_strng}")
        return output_strng

    def stats(
        self, directive: str, data: dict
    ) -> Tuple[List[List], List[List]]:
        try:
            stat = {"OK": 0, "KO": 0, "XX": 0}
            other = []
            for key in data.keys():
                data_filter = data[key][directive]
                stat[data_filter["status"]] = 1
                if data_filter["status"] == "KO":
                    other.append(
                        [
                            f"[red]{data_filter['domain']}",
                            f"[red]{data_filter['expired']} ",
                            f"[red]{data_filter['organization_name']}",
                        ]
                    )
                elif data_filter["status"] == "XX":
                    other.append(
                        [
                            f"[yellow]{data_filter['domain']}",
                            f"[yellow]{data_filter['expired']}",
                            f"[yellow]{data_filter['organization_name']}",
                        ]
                    )
            return (
                [
                    ["OK", stat["OK"]],
                    ["KO", stat["KO"]],
                    ["XX", stat["XX"]],
                ],
                other,
            )
        except KeyError as e:
            self.logger.error(str(e))
            return [], []

    def header_stats(self) -> List[str]:
        return ["Status", "Number"]

    def header_error(self) -> List[str]:
        return ["Url", "Date", "Authority"]

    def title_stats(self) -> str:
        return "SSL Verify Status"

    def title_error(self) -> str:
        return "SSL Verify Error"

    def get_markdown(self):
        """
        Return info text as Markdown
        """
        return MARKDOWN



import datetime
from typing import List, Tuple

import whois

from servergrimoire.plugin import Plugin

MARKDOWN = """
# DNS Check

Check the DNS for the domain
"""


class DNSChecker(Plugin):
    def can_handle(self, directive: str) -> bool:
        return directive == "dns_checker"

    @staticmethod
    def get_directives() -> [str]:
        return ["dns_checker"]

    def execute(self, directive: str, data: dict) -> dict:
        w = whois.whois(data["url"])
        if w["domain_name"] is None:
            output_strng = {
                "status": "XX",
                "creation": "Error trying to connect to socket",
                "expiration": "Error trying to connect to socket",
            }
        else:
            self.logger.info(w)

            if isinstance(w.expiration_date, list):
                expiration_date = w.expiration_date[0]
            else:
                expiration_date = w.expiration_date

            flag = expiration_date >= (
                datetime.datetime.now() - datetime.timedelta(days=30)
            )

            self.logger.info(flag)

            if flag:
                output_strng = {
                    "status": "OK",
                    "creation": f"{expiration_date}",
                    "expiration": f"{w.expiration_date}",
                }
            else:
                output_strng = {
                    "status": "XX",
                    "creation": f"{expiration_date}",
                    "expiration": f"{w.expiration_date}",
                }

        self.logger.info(output_strng)
        return output_strng

    def stats(
        self, directive: str, data: dict
    ) -> Tuple[List[List], List[List]]:
        stat: dict = {"OK": 0, "KO": 0, "XX": 0}
        other = []
        for key in data.keys():
            data_filter = data[key][directive]["status"]
            stat[data_filter] += 1
            if data_filter != "OK":
                try:
                    other.append(
                        [data[directive]["domain"], data[directive]["expired"]]
                    )
                except KeyError:
                    pass
        return [
            ["OK", stat["OK"]],
            ["KO", stat["KO"]],
            ["XX", stat["XX"]],
        ], other

    def header_stats(self) -> List[str]:
        return ["Status", "Number"]

    def header_error(self) -> List[str]:
        return ["URL", "Date"]

    def title_stats(self) -> str:
        return "DNS Checker Stats"

    def title_error(self) -> str:
        return "DNS Checker Error"

    def get_markdown(self):
        """
        Return info text as Markdown
        """
        return MARKDOWN



import json
import logging
from typing import List

from rich import box, print
from rich.columns import Columns, Console
from rich.logging import RichHandler
from rich.panel import Panel
from rich.progress import Progress
from rich.table import Table

from servergrimoire.configmanager import ConfigManager
from servergrimoire.operation.dnschecker import DNSChecker
from servergrimoire.operation.dnslookup import DNSLookup
from servergrimoire.operation.pagechecker import PageChecker
from servergrimoire.operation.sslverify import SSLVerify
from servergrimoire.plugin import Plugin

console = Console()


class GrimoirePage:
    def __init__(self, path):
        self.path = path
        self.setting_manager = ConfigManager(path)
        try:
            with open(self.setting_manager.data_path) as f:
                self.data = json.load(f)
        except FileNotFoundError:
            with open(self.setting_manager.data_path, "w") as f:
                json.dump({}, f)
            self.data = {}

        FORMAT = "%(message)s"
        logging.basicConfig(
            level=self.setting_manager.logger_level,
            format=FORMAT,
            datefmt="[%X]",
            handlers=[RichHandler()],
        )

        self.logger = logging.getLogger("rich")

    def __get_directives_and_class(self) -> dict:
        """
        Return a dict with all directories and theire class
        """
        dict_directives = {}
        for _class in self.__get_directives_class():
            for e in _class.get_directives():
                dict_directives[e] = _class
        return dict_directives

    def __get_urls(self):
        """
        Return a array with all urls and theire class
        """
        return self.__get_directives_class().keys()

    def __get_directives_class(self) -> List[Plugin]:
        directive = [DNSChecker, DNSLookup, SSLVerify, PageChecker]
        # TODO Add reader from folder
        return directive

    def __get_directives_str(self) -> List[str]:
        """
        Return all directive into a array
        """
        arr_directives = []
        for _class in self.__get_directives_class():
            for e in _class.get_directives():
                arr_directives.append(e)
        return arr_directives

    def __get_urls_all(self) -> List[str]:
        """
        Return all urls into a array
        """
        try:
            return self.data["server"].keys()
        except Exception:
            return []

    def run(self, command=None, url=None):
        """
        Launch command for plugin
        """
        map_command = self.__get_directives_and_class()
        if command is None:
            command_to_run = self.__get_directives_str()
        else:
            command_to_run = [command]
        url_to_run = None
        if url is None:
            url_to_run = self.__get_urls_all()
        else:
            url_to_run = [url]

        with Progress() as progress:
            tasks = {}
            for command in command_to_run:
                tasks[command] = progress.add_task(
                    f"[cyan]{command}", total=(len(url_to_run))
                )

            for url in url_to_run:
                for command in command_to_run:
                    return_val = map_command[command]().execute(
                        command, self.data["server"][url]
                    )
                    self.data["server"][url][command] = return_val
                    progress.update(tasks[command], advance=1)

        with open(self.setting_manager.data_path, "w") as json_file:
            json.dump(self.data, json_file)

    def stats(self, command=None, url=None, short=False) -> None:
        """
        Launch stats command for plugin
        """
        map_command = self.__get_directives_and_class()
        if command is None:
            command_to_run = self.__get_directives_str()
        else:
            command_to_run = [command]
        if url is None:
            url_to_run = self.__get_urls_all()
        else:
            url_to_run = [url]

        if short:
            commands = []
            for command in command_to_run:
                data = {
                    k: self.data["server"][k]
                    for k in self.data["server"].keys() & set(url_to_run)
                }
                plugin = map_command[command]()
                _, errors = plugin.stats(command, data)
                commands.append(len(errors))
            stats_tab = self.__to_table(
                zip(command_to_run, commands),
                "ServerGrimoire",
                ["Command", "# Error"],
            )
            stats_tab.box = box.SIMPLE
            print(stats_tab)

            return
        for command in command_to_run:
            data = {
                k: self.data["server"][k]
                for k in self.data["server"].keys() & set(url_to_run)
            }
            plugin = map_command[command]()
            stats, errors = plugin.stats(command, data)
            stats_tab = self.__to_table(
                stats, plugin.title_stats(), plugin.header_stats()
            )

            error_tab = self.__to_table(
                errors, plugin.title_error(), plugin.header_error()
            )
            print(
                Panel(
                    Columns([stats_tab, error_tab]),
                    title=command,
                    highlight=True,
                )
            )

    def __to_table(
        self, matrix_data: List[List], title: str, header: List[str]
    ) -> Table:
        table = Table(title=title, box=box.MINIMAL, expand=True)
        for ele in header:
            table.add_column(ele)
        for row in matrix_data:
            row = list(map(str, row))
            table.add_row(*row)
        return table

    def info(self, command=None, url=None) -> None:
        """
        Launch info command for plugin
        """

        map_command = self.__get_directives_and_class()
        if command is None:
            command = self.__get_directives_str()
        for c in command:
            map_command[c]().info()

    def add(self, url) -> bool:
        """
        Add command for url
        """
        for e in url:
            if self.data.get("server") is None:
                self.data["server"] = {}
            if self.data["server"].get(e) is None:
                self.data["server"][e] = {"url": e}
                self.logger.info(f"Adding {url}")
        with open(self.setting_manager.data_path, "w") as json_file:
            json.dump(self.data, json_file)
        return True

    def remove(self, url=None) -> bool:
        """
        Remove command for url
        """
        self.data["server"].pop(url, None)
        with open(self.setting_manager.data_path, "w") as json_file:
            json.dump(self.data, json_file)
        self.logger.info(f"Removing {url}")
        return True



from importlib import import_module

import click

from servergrimoire.app import GrimoirePage


def dynamic_import(abs_module_path, class_name):
    module_object = import_module(abs_module_path)
    target_class = getattr(module_object, class_name)
    return target_class


@click.group()
@click.option(
    "--c",
    "-config",
    help="Path of the config if different from standard",
    default=None,
)
@click.pass_context
def grimoire(ctx, c):
    ctx.obj = GrimoirePage(c)


@grimoire.command(help="Run the command")
@click.option(
    "--c",
    "-command",
    help="Command to run. If not insert launch all the commands",
)
@click.option("--u", "-url", help="On which url launch the command")
@click.option(
    "--stats/--no-stats", default=False, help="Launch stats after the run"
)
@click.pass_context
def run(ctx, c, u, stats):
    ctx.obj.run(c, u)
    if stats:
        ctx.obj.stats(c, u)


@grimoire.command(help="Show the stats")
@click.option(
    "--c",
    "-command",
    help="Stats to return. If not insert launch all the commands",
)
@click.option("--u", "-url", help="On which url return the stats")
@click.option("--s", "-short", is_flag=True, help="Short version of the stats")
@click.pass_context
def stats(ctx, c, u, s):
    ctx.obj.stats(c, u, s)


@grimoire.command(help="Show the info")
@click.option("--u", "-url", help="On which url return the info")
@click.option("--c", "-command", help="On which directive return the info")
@click.pass_context
def info(ctx, c, u):
    ctx.obj.info(command=c, url=u)


@grimoire.command(help="Add the url to the command check")
@click.option("--u", "-url", help="Url to add", multiple=True)
@click.pass_context
def add(ctx, u):
    ctx.obj.add(url=u)


@grimoire.command(help="Remove the url to the command check")
@click.option("--u", "-url", help="Url to remove")
@click.pass_context
def remove(ctx, u):
    ctx.obj.remove(u)


@grimoire.command(help="Show the hello message")
def hello():
    print(
        """
.d8888b.
d88P  Y88b
Y88b.
 "Y888b.    .d88b.  888d888 888  888  .d88b.  888d888
    "Y88b. d8P  Y8b 888P"   888  888 d8P  Y8b 888P"
      "888 88888888 888     Y88  88P 88888888 888
Y88b  d88P Y8b.     888      Y8bd8P  Y8b.     888
 "Y8888P"   "Y8888  888       Y88P    "Y8888  888



 .d8888b.          d8b                        d8b
d88P  Y88b         Y8P                        Y8P
888    888
888        888d888 888 88888b.d88b.   .d88b.  888 888d888 .d88b.
888  88888 888P"   888 888 "888 "88b d88""88b 888 888P"  d8P  Y8b
888    888 888     888 888  888  888 888  888 888 888    88888888
Y88b  d88P 888     888 888  888  888 Y88..88P 888 888    Y8b.
 "Y8888P88 888     888 888  888  888  "Y88P"  888 888     "Y8888
    """
    )



import errno
import json
import logging
import os
from pathlib import Path

from rich.logging import RichHandler


class ConfigManager:
    def __init__(self, path):
        self.config = {}
        if path is None:
            self.path = Path.home() / ".servergrimoire/config.json"
        else:
            self.path = path

        if not os.path.exists(self.path):
            if not os.path.exists(os.path.dirname(self.path)):
                try:
                    os.makedirs(os.path.dirname(self.path))
                except OSError as exc:  # Guard against race condition
                    if exc.errno != errno.EEXIST:
                        raise
            self.__create_default__()
        else:
            with open(self.path) as data_file:
                self.config = json.load(data_file)
        self.__preset__()

        self.__write_config__()

    def __preset__(self):
        FORMAT = "%(message)s"
        logging.basicConfig(
            level=self.logger_level,
            format=FORMAT,
            datefmt="[%X]",
            handlers=[RichHandler()],
        )

        logger = logging.getLogger("rich")
        logger.debug(f"Data path {self.data_path}")
        logger.debug(f"Logger level is {self.logger_level}")

        self.config["logger_level"] = str(self.logger_level)

    def __write_config__(self):
        with open(Path(self.path), "w") as outfile:
            self.__preset__()
            json.dump(self.config, outfile)

    def __create_default__(self) -> dict:
        self.__write_config__()
        return self.config

    @property
    def data_path(self):
        return self.config["data_path"]

    @data_path.setter
    def data_path(self, var):
        self.config["data_path"] = var
        self.__write_config__()

    @data_path.getter
    def data_path(self):
        return self.config.get(
            "data_path", Path.home() / ".servergrimoire/data.json"
        )

    @property
    def logger_level(self):
        return self.config["logger_level"]

    @logger_level.setter
    def logger_level(self, var):
        self.config["logger_level"] = var

    @logger_level.getter
    def logger_level(self):
        return self.config.get("logger_level", "ERROR")

    @property
    def folder_script(self):
        return self.config["folder_script"]

    @folder_script.setter
    def folder_script(self, var):
        self.config["folder_script"] = var
        self.__write_config__()

    @folder_script.getter
    def folder_script(self):
        return self.config.get(
            "folder_script", Path.home() / ".servergrimoire/script/"
        )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['servergrimoire', 'servergrimoire.operation']

package_data = \
{'': ['*']}

install_requires = \
['Click>=7.1.2,<8.0.0',
 'dnspython>=2.1.0,<3.0.0',
 'pyOpenssl>=19.1.0,<20.0.0',
 'python-whois>=0.7.3,<0.8.0',
 'requests>=2.24.0,<3.0.0',
 'rich>=9.6.2,<10.0.0']

entry_points = \
{'console_scripts': ['servergrimoire = servergrimoire.__main__:launcher']}

setup_kwargs = {
    'name': 'servergrimoire',
    'version': '1.7.5',
    'description': 'Package for record and store info about servers and their stuffs',
    'long_description': '```\n.d8888b.\nd88P  Y88b\nY88b.\n "Y888b.    .d88b.  888d888 888  888  .d88b.  888d888\n    "Y88b. d8P  Y8b 888P"   888  888 d8P  Y8b 888P"\n      "888 88888888 888     Y88  88P 88888888 888\nY88b  d88P Y8b.     888      Y8bd8P  Y8b.     888\n "Y8888P"   "Y8888  888       Y88P    "Y8888  888\n\n\n\n .d8888b.          d8b                        d8b\nd88P  Y88b         Y8P                        Y8P\n888    888\n888        888d888 888 88888b.d88b.   .d88b.  888 888d888 .d88b.\n888  88888 888P"   888 888 "888 "88b d88""88b 888 888P"  d8P  Y8b\n888    888 888     888 888  888  888 888  888 888 888    88888888\nY88b  d88P 888     888 888  888  888 Y88..88P 888 888    Y8b.\n "Y8888P88 888     888 888  888  888  "Y88P"  888 888     "Y8888\n```\n\n[![Maintainability](https://api.codeclimate.com/v1/badges/4aece0d4c29b48cfcea4/maintainability)](https://codeclimate.com/github/fundor333/servergrimoire/maintainability)\n[![Test Coverage](https://api.codeclimate.com/v1/badges/4aece0d4c29b48cfcea4/test_coverage)](https://codeclimate.com/github/fundor333/servergrimoire/test_coverage)\n![PyPI - License](https://img.shields.io/pypi/l/servergrimoire)\n![PyPI](https://img.shields.io/pypi/v/servergrimoire)\n![PyPI - Status](https://img.shields.io/pypi/status/servergrimoire)\n![PyPI - Wheel](https://img.shields.io/pypi/wheel/servergrimoire)\n\nThis module gives you some command to check URLs, domains and other things in an automatied way.\n\nAll config and data are saved as dotfiles in your home directory and it works on Windows, Mac, and Linux systems granted\nyou have Python installed.\n\n# Command\n\nThis is a partial table of commands. For the complete one we suggest you to launch the --help command\n\n|        Command        | Option   | Explanation                              |\n|:---------------------:|----------|------------------------------------------|\n| servergrimoire --help |          | Print the help of the program            |\n| servergrimoire run    | --u, --c | Run the command for the url described    |\n| servergrimoire add    | --u      | Add the URL into the file for running    |\n| servergrimoire remove | --u      | Remove the url from the file for running |\n| servergrimoire stats  | --u,--c  | Print the stats of the last run made     |\n\nFor now we have the following commands\n\n| Command     | What does it?                                   |\n|-------------|-------------------------------------------------|\n| ssl_check   | Check if the domain has a valid SSL certificate |\n| dns_lookup  | Save the DNS lookup for the domain              |\n| dns_checker | Make a whois and save the domain expiration day |\n\n# Files\n\nServer Grimoire has two file to work with:\n\n* A config file .servergrimoire/config.json\n* A data file .servergrimoire/data.json\n\nThey are .json file if you want to edit them.\n',
    'author': 'Fundor333',
    'author_email': 'fundor333@fundor333.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/fundor333/servergrimoire',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
